      SUBROUTINE MODA
C
C*****
C
C     DUMMY DECK FOR MODULE MODA   SEE USERS MANUAL SECTION 5.3
C                                  FOR MODULE PROPERTIES CHECK XMPLBD
C                                  OR USE DIAG 29
C
C*****
C
      INTEGER IPARM , PARM12 , PARM13
C     INTEGER OUTFIL(4)
C
      COMMON /BLANK/ PARM(5),IPARM(5),PARM11,PARM12,PARM13
C
C     DATA OUTFIL /201,202,203,204/
C
      RETURN
      END
