      SUBROUTINE DDR
C
C*****
C
C     DUMMY DECK FOR MODULE DDR    SEE USERS MANUAL SECTION 5.3
C                                  FOR MODULE PROPERTIES CHECK XMPLBD
C                                  OR USE DIAG 29
C
C*****
C
      INTEGER PARM1,PARM2,PARM3
C     INTEGER OUTFIL
C
      COMMON /BLANK/ PARM1(2),PARM2(2),PARM3(2)
C
C     DATA INFILE/101/, OUTFIL/201/
C
      RETURN
      END
