      SUBROUTINE RE2AL (RE,ALPH)
C
      EXTERNAL        LSHIFT
      INTEGER         ALPH(2)
      COMMON /SYSTEM/ IBUF,NOUT,DUMMY(37),NBPW
C
      CALL FP2A8 (*40,RE,ALPH)
      IF (NBPW-60) 30,10,20
C
C     FOR 60- OR 64- BIT MACHINES, SAVE THE SECOND HALF OF REAL NUMBER
C     IN THE SECOND ALPH WORD. THAT IS -
C     THE FULL REAL NUMBER IS IN ALPH(1), ALL 8 BYTES, OR
C     FIRST 4 BYTES IN ALPH(1), AND LAST 4 BYTES IN ALPH(2)
C
 10   ALPH(2) = LSHIFT(ALPH(1),24)
      GO TO 30
 20   ALPH(2) = LSHIFT(ALPH(1),32)
 30   RETURN
C
 40   WRITE  (NOUT,50)
 50   FORMAT (99X,'(IN FP2A8, CALLED FROM RE2AL)')
      CALL MESAGE (-61,0,0)
      GO TO 30
      END
