      SUBROUTINE OUTPT
C
C*****
C
C     DUMMY DECK FOR MODULE OUTPUT    SEE USERS MANUAL SECTION 5.3
C                                     FOR MODULE PROPERTIES CHECK XMPLBD
C                                     OR USE DIAG 29
C
C*****
C
      INTEGER PARM
C
      COMMON /BLANK/ PARM
C
C     DATA INFILE /101/
C
      RETURN
      END
