      SUBROUTINE FORM2(UDDIP1,UDIPRM,UIPRM,PIPRM,IBUF)
C*******
C     FORM2 GENERATES THE VECTORS NECESSARY TO CHANGE THE TIME STEP
C
C     THIS ROUTINE IS SUITABLE FOR SINGLE PRECISION OPERATION
C*******
      DIMENSION UDDIP1(1),UDIPRM(1),UIPRM(1),PIPRM(1),IBUF(1)
C
      COMMON   /TRDXX /  IFILK(7)  ,IFILM(7) ,IFILB(7)
C*******
C     FORM UDOT(I+1), UDDOT(I+1), UDOT-(I), AND U-(I)
C*******
      CALL MATVEC(UDDIP1(1),PIPRM(1),IFILM(1),IBUF)
      CALL MATVEC(UDIPRM(1),PIPRM(1),IFILB(1),IBUF)
      CALL MATVEC(UIPRM(1),PIPRM(1),IFILK(1),IBUF)
      RETURN
      END
