      SUBROUTINE SMCDMP1 (  ZI, ZR, ZD )
      INTEGER          ZI(10)
      REAL             ZR(10)
      DOUBLE PRECISION ZD(10)
      INCLUDE   'SMCOMX.COM'
      DO 1000 ICOL = 1, NCOL
      IND = ( ICOL-1 ) * 4 + 1
      INDEXR = ZI( IND )
      IF ( ZI( INDEXR ) .EQ. 0 ) GO TO 700
      ICOLUM  = ZI( INDEXR   )
      LENROWS = ZI( INDEXR+1 )
      NWORDS  = ZI( INDEXR+2 )
      LENVALS = ZI( INDEXR+3 )
      WRITE( NOUT,901) ICOLUM
901   FORMAT(/,' -----------------------------COLUMN NUMBER   =',I10)
      WRITE ( NOUT, 900 )  ZI(IND), ZI(IND+1), ZI(IND+2), ZI(IND+3)
     &,                    LENROWS, LENVALS, NWORDS
900   FORMAT(20X,' COLUMN DIRECTORY: INDEX                    =',I10
     &,/    ,20X,' FIRST COLUMN DATA NEEDED FOR THIS PIVOT    =',I10
     &,/    ,20X,' LAST PIVOT COLUMN TO USE THIS COLUMN       =',I10
     &,/    ,20X,' SAVPOS                                     =',2X,Z8
     &,/    ,20X,' NUMBER OF WORDS DEFINING ROW NUMBERS       =',I10
     &,/    ,20X,' NUMBER OF NON-ZERO TERMS IN THIS COLUMN    =',I10
     &,/    ,20X,' TOTAL NUMBER OF WORDS ALLOCATED FOR COLUMN =',I10
     & )
      INDEXR = INDEXR + 4
      INDEXV = INDEXR+LENROWS
      INDEXVD= INDEXV / 2 + 1
      IEND   = INDEXV
50    IROW   = ZI( INDEXR )
      NTERMS = ZI( INDEXR+1 )
      WRITE( NOUT,905) IROW, NTERMS, KTYPE
905   FORMAT(' ROW, TERMS, TYPE=',3I10)
      GO TO ( 100, 200, 300, 400 ), KTYPE
100   WRITE( NOUT,906) (ZR(INDEXV+K-1),K=1,NTERMS)
906   FORMAT( 5E16.8 )
      INDEXV = INDEXV + NTERMS
      INDEXR = INDEXR + 2
      GO TO 500
200   WRITE( NOUT,907) (ZD(INDEXVD+K-1),K=1,NTERMS)
907   FORMAT( 5D16.8 )
      INDEXV = INDEXV  + 2*NTERMS
      INDEXVD= INDEXVD + NTERMS
      INDEXR = INDEXR + 2
      GO TO 500
300   WRITE( NOUT,906) (ZR(INDEXV+K-1),K=1,2*NTERMS)
      INDEXV = INDEXV + 2*NTERMS
      INDEXR = INDEXR + 2
      GO TO 500
400   WRITE( NOUT,907) (ZD(INDEXVD+K-1),K=1,2*NTERMS)
      INDEXV = INDEXV  + 4*NTERMS
      INDEXVD= INDEXVD + 2*NTERMS
      INDEXR = INDEXR + 2
      GO TO 500
500   IF ( INDEXR .GE. IEND ) GO TO 1000   
      GO TO 50
700   WRITE( NOUT,908) 
908   FORMAT( ' COLUMN HAS BEEN PUT TO SPILL FILE')
1000  CONTINUE
7777  RETURN
      END
