      SUBROUTINE DUMOD1
C
C
C     DUMMY DECK FOR MODULE DUMMOD1 - SEE USER'S MANUAL SECTION 5.6.
C                                     FOR MODULE PROPERTIES, CHECK
C                                     SUBROUTINE XMPLDD OR USE DIAG 31.
C
C     REVISED 5/91  BY G.CHAN/UNISYS
C     THIS DUMMY MODULE IS IN LINK3 ONLY (SEE XLNKDD). IT CAN BE USED TO
C     FORCE NASTRAN TO DO A LINK SWITCHING AND THEN CONTINUE. e.g.
C     MODULE XXX (NOT IN LINK3) GETS INTO TROUBLE WITH SFM 3018
C     (REQUIREMENTS EXCEED AVAILABLE FILES). USE DMAP ALTER TO CALL THIS
C     DUMOD1 MODLUE A STEP AHEAD OF MODULE XXX. THUS NASTRAN IS FORCED
C     TO DO A LINKSWITCH AND HOUSEKEEPING MODULE XSFA IS CALLED TO CLEAN
C     UP THE FILE ALLOCATION TABLE. THIS MAY SOLVE THE SFM 3018 PROBLEM.
C
C
      INTEGER PARM1,PARM2,PARM3,PARM4,PARM5
C     INTEGER INFILE(1),OUTFIL(2),SCRFIL(3)
C
      COMMON /BLANK / PARM1,PARM2,PARM3,PARM4,PARM5
C     COMMON /ZZZZZZ/ X(1)
C
C     DATA INFILE /101/
C     DATA OUTFIL /201,202/
C     DATA SCRFIL /301,302,303/
C
      RETURN
      END
