      SUBROUTINE DSSIZE ( NAMFIL, NCOLS, NTERMS, NSTRGS, NWDTRM )
C
C   DSSIZE DETERMINES THE SIZE OF A GIVEN MATRIX FILE
C      NCOLS  = NUMBER OF COLUMNS
C      NTERMS = TOTAL NUMBER OF NON-ZERO TERMS IN MATRIX
C      NSTRGS = TOTAL NUMBER OF STRINGS OF CONSECUTIVE TERMS IN MATRIX
C      NWDTRM = NUMBER OF WORDS PER TERM
C
      INCLUDE 'DSIOF.COM'
      COMMON / ZZZZZZ / MEM( 4 )
      INTEGER   MCB(7)
      CALL GETURN( NAMFIL )
      IF ( IFILEX .EQ. 0 ) GO TO 701
      MCB( 1 ) = NAMFIL
      CALL RDTRL ( MCB )
      NCOLS  = MCB( 2 )
      NSTRGS = FCB( 16, IFILEX )
      NTERMS = FCB( 17, IFILEX )
      NWDTRM = 2
      IF ( MCB( 5 ) .EQ. 1 ) NWDTRM = 1
      IF ( MCB( 5 ) .EQ. 4 ) NWDTRM = 4
      GO TO 777
701   NTERMS = 0
      NSTRGS = 0
      NCOLS  = 0
      NWDTRM = 0
777   CONTINUE
      RETURN
      END
