      SUBROUTINE SDRCHK (FORVEC,CFRVEC,LVEC,KONT)
C   THIS ROUTINE IS USED BY ELEMENT SUBROUTINES THAT DETERMINE IF THE
C REQUESTED STRESS/FORCE PRECISION IS AVAILABLE...
C-----
      REAL    FORVEC(LVEC) ,CFRVEC(LVEC)
      COMMON /SDR2X9/ NCHK(5),TWOTOP,FNCHK
C
       DO 20 I = 1,LVEC
      IF (CFRVEC(I).EQ.0.0) R = 1.0E0
      IF (CFRVEC(I).NE.0.0) R = ABS (FORVEC(I)/CFRVEC(I) )
      IF (R.GT.1.001) R = 1.0E0
      IF (R.EQ.0.0) RJ = TWOTOP
      IF (R.NE.0.0) RJ = TWOTOP + ALOG10 (R)
      IF (RJ.LT.0.0) RJ = 0.0
      CFRVEC(I) = RJ
      IF (RJ.LT.FNCHK) KONT = KONT + 1
   20 CONTINUE
C-----
      RETURN
      END
