      SUBROUTINE ODUMX (Z)
C
      ENTRY ODUM1 (Z)
      GO TO 10
C
      ENTRY ODUM2 (Z)
      GO TO 10
C
      ENTRY ODUM3 (Z)
      GO TO 10
C
      ENTRY ODUM4 (Z)
      GO TO 10
C
      ENTRY ODUM5 (Z)
      GO TO 10
C
      ENTRY ODUM6 (Z)
      GO TO 10
C
      ENTRY ODUM7 (Z)
      GO TO 10
C
      ENTRY ODUM8 (Z)
      GO TO 10
C
      ENTRY ODUM9 (Z)
C
   10 NOTUSE = Z
      RETURN
      END
