      SUBROUTINE SDCOMP ( *, ZI, ZR, ZD )
      INCLUDE 'SMCOMX.COM'
      COMMON / LOGOUT / LOUT
      CALL SSWTCH ( 44, I44 )
      IF ( I44 .NE. 0 ) GO TO 100
C
C CALL NEW SYMMETRIC DECOMPOSITION ROUTINE 12/95
C      
      CALL SMCOMP ( *710, ZI, ZR, ZD )
      IF ( IERROR .NE. 1 ) GO TO 700
      WRITE ( LOUT, 901 )
901   FORMAT(8X,'INSUFFICIENT OPEN CORE FOR NEW SYMMETRIC DECOMPOSITION'
     &,/,8X,'WILL SWITCH AND USE OLD METHOD.')
C
C OTHERWISE, CALL SYMMETRIC DECOMPOSITION OF RELEASE 94 AND EARLIER
C
100   CALL SDCOMPX( *710, ZI, ZR, ZD )
700   CONTINUE
      RETURN
710   CONTINUE
      RETURN 1
      END
