      SUBROUTINE EMGSOC (ICORE,NCORE,HEAT)
C
C     THIS .MDS VERSION IS USED ONLY IN THE VIRTUAL MACHINES (IBM, VAX,
C     AND UNIX)
C     CDC & UNIVAC, NON-VIRTUAL MACHINES, SHOULD USE THE EMGSOC.MIS
C     VERSION
C
C     ICORE = RELATIVE ADDRESS OF FIRST WORD OF OPEN CORE.
C     NCORE = RELATIVE ADDRESS OF FINAL WORD OF OPEN CORE.
C
C     IFILE = GINO FILE WHOSE TRAILER BITS INDICATE ACTIVE COMMON GROUPS
C
C     BOUNDARY ALIGNMENT IS ASSURED BY THE FACT THAT ALL COMMON BLOCKS
C     START AT AN ODD ADDRESS.
C
      COMMON /MACHIN/ MACH
      COMMON /ZZEMGX/ IXXX
C
      NCORE = KORSZ(IXXX)
      ICORE = 3
      IF (MACH.EQ.3 .OR. MACH.EQ.4) STOP ' EMGSOC'
      RETURN
      END
