      SUBROUTINE OFPPNT (OUT,NWDS,FMT)
C
CWKBD LOGICAL         DEBUG
CWKBR INTEGER         OUT(NWDS), FMT(300)
      INTEGER         OUT(NWDS)
      CHARACTER*1     FMT(1200)
CWKBI
      COMMON /MACHIN/ MACHX
      COMMON /SYSTEM/ SYSBUF,    L
CWKBD DATA    DEBUG / .FALSE. /
C
CWKBD IF (DEBUG) WRITE (L,10) (FMT(K),K=1,32)
 10   FORMAT (' FMT=',32A4)
CWKBR 5/95     IF ( MACHX.EQ.2 .OR. MACHX.EQ.5  )  
      IF ( MACHX.EQ.2 .OR. MACHX.EQ.5 .OR. MACHX .EQ. 21  )  
     *     WRITE (L,FMT,IOSTAT=IOSXX) (OUT(K),K=1,NWDS)
CWKBR 5/95      IF ( MACHX.NE.2 .AND. MACHX.NE.5 )  
      IF ( MACHX.NE.2 .AND. MACHX.NE.5 .AND. MACHX .NE. 21 )  
     *     CALL FORWRT (FMT, OUT, NWDS)
      RETURN
      END
