      SUBROUTINE MODB
C
C*****
C
C     DUMMY DECK FOR MODULE MODB   SEE USERS MANUAL SECTION 5.3
C                                  FOR MODULE PROPERTIES CHECK XMPLBD
C                                  OR USE DIAG 29
C
C*****
C
      INTEGER IPARM1   , IPARM2
C     INTEGER INFILE(3), OUTFIL(4)
C
      COMMON /BLANK/ PARM(4),IPARM1(3),PARM8,IPARM2(3)
C
C     DATA INFILE /101,102,103/
C     DATA OUTFIL /201,202,203,104/
C
      RETURN
      END
