      SUBROUTINE DPPS(KS,I,J1,J2,SGR,CGR,YS,ZS,NBARAY,NCARAY,DT,WORK)
C   ***   GENERATES ROWS OF THE  DPP  SUBMATRIX USING
C         SUBROUTINE  SUBP
      DIMENSION YS(1),ZS(1),NBARAY(1),NCARAY(1),WORK(1)
      COMPLEX DT(1), SUM
      COMMON /DLCOM / NP,NSTRIP,NTP,F,NJJ,NEXT,LENGTH,
     1                INC,INB,IYS,IZS,IEE,ISG,ICG,
     2                IXIC,IDELX,IXLAM,IDT,
     3  ICORE
      L    = 1
C  L IS THE PANEL NUMBER ASSOCIATED WITH SENDING   POINT  J
      LS   = 1
C  LS IS THE STRIP NUMBER ASSOCIATED WITH SENDING   POINT  J
      NBXS = NBARAY(L)
      NC1  = NCARAY(L)
      NBCUM= NC1
      YREC = YS(KS)
      ZREC = ZS(KS)
      DO   20  J=J1,J2
      CALL SUBP(I,L,LS,J,SGR,CGR,YREC,ZREC,SUM,
     1 WORK(IXIC),WORK(IDELX),WORK(IEE),WORK(IXLAM),
     2  WORK(ISG),WORK(ICG),YS,ZS)
      DT(J)= SUM
      IF (J.EQ.J2)  GO TO   20
      IF (J.LT.NBXS)   GO TO  10
      L    = L+1
      NC1  = NCARAY(L)
      NBXS = NBARAY(L)
   10 CONTINUE
      IF (J.LT.NBCUM)  GO TO  20
      LS   = LS+1
      NBCUM= NBCUM+NC1
   20 CONTINUE
      RETURN
      END
