      SUBROUTINE MXCIDS(*,Z,MSET,MSZE,NWDS,USET,NSTRT,SNAM)
C-----
C   THIS SUBROUTINE CREATES A LIST OF SUBSTRUCTURE NAMES AT Z(1)
C AND AN ARRAY AT Z(NSTRT) OF LENGTH MSZE*NWDS WITH THE FIRST TWO WORDS
C OF EACH ENTRY AS,
C     1 - EXTERNAL ID * 10 + COMPONENT
C     2 - POINTER TO FIRST WORD OF SUBSTRUCTURE NAME...
C
C INPUT
C     Z     = OPEN CORE - Z(1) TO Z(NSTRT-1)
C     MSET  = ONE WORD BCD IDENTIFING SET
C     MSZE  = NUMBER OF COLUMNS IN MATRIX
C     NWDS  = NUMBER WORDS/ENTRY DESIRED (2 MINIMUM)
C     USET  = USET GINO FILE NAME
C     NSTRT = LOCATION OF FIRST OF FOUR (4) BUFFERS.
C     SNAM  = SUBSTRUCTURE NAME BEING SOLVED (2 WORD BCD).
C OUTPUT
C     *     = TASK NOT COMPLETED
C     Z     = SUBSTRUCTURE NAMES + COLUMN IDENTIFIERS (SEE ABOVE)
C     NSTRT = FIRST WORD OF COLUMN IDENTIFIERS
C-----
C
C       N O T   C O D E D   Y E T
C
        IF (MSET.EQ.1) RETURN
      RETURN 1
        END
