      SUBROUTINE DUMOD4
C
C*****
C
C     DUMMY DECK FOR MODULE DUMMOD4 - SEE USER'S MANUAL SECTION 5.6.
C                                     FOR MODULE PROPERTIES, CHECK
C                                     SUBROUTINE XMPLDD OR USE DIAG 31.
C
C*****
C
      COMPLEX          PARM9
C
      DOUBLE PRECISION PARM8,PARM10
C
      INTEGER          PARM1,PARM2,PARM3,PARM4,PARM7
      INTEGER          INFILE(8),OUTFIL(8),SCRFIL(10)
C
      COMMON /BLANK /  PARM1,PARM2,PARM3,PARM4,PARM5,PARM6,
     1                 PARM7(2),PARM8,PARM9,PARM10(2)
      COMMON /ZZZZZZ/  X(1)
C
      DATA    INFILE/  101,102,103,104,105,106,107,108/
      DATA    OUTFIL/  201,202,203,204,205,206,207,208/
      DATA    SCRFIL/  301,302,303,304,305,306,307,308,309,310/
C
      RETURN
      END
