      SUBROUTINE DSMG1
C
C     THIS ROUTINE IS THE DRIVER FOR THE DIFFERENTIAL STIFFNESS MATRIX
C     GENERATOR MODULE OF THE NASTRAN SYSTEM.  SUBROUTINE DS1 APPENDS
C     TEMPERATURE, ELEMENT DEFORMATION AND DISPLACEMENT INFORMATION TO
C     THE ECPT DATA BLOCK AND A SCRATCH FILE, ECPTDS, OF THIS MERGED
C     INFORMATION IS CREATED.  SUBROUTINE DS1A IS STRUCTURED IDENTICALLY
C     TO SMA1A. IT READS THE ECPTDS FILE AND CREATES A SECOND ORDER
C     APPROXIMATION TO THE KGG, WHICH IS CALLED KDGG.
C
C     DMAP CALL -
C
C     DSMG1    CASECC,GPTT,SIL,EDT,UGV,CSTM,MPT,ECPT,GPCT,DIT/KDGG/
C
      CALL DS1 (IARG)
      IF (IARG .GT. 0) GO TO 10
C
C     ECPTDS IS EMPTY. WRITE MESSAGE AND CALL EXIT.
C
      CALL MESAGE (30,81,0)
      CALL MESAGE (-61,0,0)
   10 CALL DS1A
      RETURN
      END
