      SUBROUTINE ALAMDA (ARG,Y,BLAMDA)
C
C     SUBROUTINE FOR COMPUTING LAMDA
C
      COMPLEX BLAMDA,AI,C1
C
      COMMON/BLK1/SCRK,SPS,SNS,DSTR,AI,PI,DEL,SIGMA,BETA,RES
C
      SCRK1= ABS(SCRK)
      ARG1=  ABS(ARG)
      S1=(ARG-DEL)*SPS+SIGMA
      IF( SCRK1.GT.ARG1) GO TO 10
      GAM=SQRT(ARG**2-SCRK**2)
      C1=COS(GAM*(SNS-Y))-CEXP(AI*S1)*COS(GAM*Y)
      C2=COS(SNS*GAM)-COS(S1)
      BLAMDA=C1/C2
      RETURN
   10 CONTINUE
      GAM=SQRT(SCRK**2-ARG**2)
      C1=COSH(GAM*(SNS-Y))-CEXP(AI*S1)*COSH(GAM*Y)
      C2=COSH(SNS*GAM)-COS(S1)
      BLAMDA=C1/C2
      RETURN
      END
