      SUBROUTINE NASOPN ( *, LU, DSN )
      CHARACTER*80  IFILE, DSN
      INCLUDE 'NASNAMES.COM'
      LOGICAL IEXIST
      KLEN = INDEX( RFDIR, ' ' )
      IFILE = RFDIR(1:KLEN-1) // '/NASINFO'
      DSN = IFILE
      INQUIRE ( FILE=IFILE, EXIST=IEXIST )
      IF ( .NOT. IEXIST ) GO TO 100
      OPEN ( UNIT=LU, FILE=IFILE, STATUS='OLD', ERR=100 )
      RETURN
100   RETURN 1
      END
