      SUBROUTINE XYPRPT
C
C*****
C
C     DUMMY DECK FOR MODULE XYPRNPLT - SEE USER'S MANUAL SECTION 5.6.
C                                      FOR MODULE PROPERTIES, CHECK
C                                      SUBROUTINE XMPLDD OR USE DIAG 31.
C
C*****
C
C     INTEGER INFILE
C
C     NO PARAMETERS, OUTPUTS OR SCRATCH FILES
C
C     DATA INFILE /101/
C
      RETURN
      END
