      SUBROUTINE DSCPOS ( FILE, ICBLK, ICLR, ICBP )
C
C RETURNS THE CURRENT BLOCK NUMBER "ICBLK", CURRENT LOGICAL RECORD
C POINTER "ICLR" AND CURRENT BUFFER POINT "ICBP" FOR "FILE"
C
      INCLUDE 'DSIOF.COM'
      INTEGER          FILE
      NAME   = FILE
      CALL DSGEFL
      ICBLK  = FCB( 4, IFILEX )
      ICLR   = INDCLR - INDBAS + 1
      ICBP   = INDCBP - INDBAS + 1
      RETURN
      END
