      SUBROUTINE MAKMCB (MCB,IFILE,IROW,IF,IT)
C
      INTEGER MCB(7)
C
      MCB(1) = IFILE
      MCB(2) = 0
      MCB(3) = IROW
      MCB(4) = IF
      MCB(5) = IT
      MCB(6) = 0
      MCB(7) = 0
C
      RETURN
C
      END
