      SUBROUTINE MPYAD (ZZ      ,Z      ,ZD      )
C
C     THE FOLLOWING DEFINES THE VARIOUS I/O METHODS AND STORAGE METHODS USED
C  BY THE DIFFERENT MULTIPLY-ADD METHODS.  
C
C  IN REGARDS TO THE NEW METHODS BELOW, WHEN MULTIPLE COLUMNS OF A MATRIX
C  ARE STORED AND READ BY GETSTR, THEN THE MATRIX IS STORED IN MEMORY IN 
C  COMPACT FORM.  SEE SUBROUTINES 'MMARM1,2,3,4' FOR A DESCRIPTION OF 
C  THIS COMPACT FORM.  WHEN ONLY A SINGLE COLUMN OF A MATRIX IS STORED 
C  AND IT IS BEING READ BY GETSTR, IT IS STORED IN COMPACT FORM IN MEMORY.  
C  SEE SUBROUTINES 'MMARC1,2,3,4' FOR A DESCRIPTION OF THIS FORM.
C
C   METHOD     METHOD OF READING MATRIX    MULTIPLE COLUMNS OF MATRIX STORED
C                 A        B       C           A         B        D
C  OLD METHODS
C     1         INTPK   UNPACK   UNPACK       NO         YES      YES
C     2T        GETSTR  UNPACK   INTPK        YES        NO       NO
C     2NT       GETSTR  INTPK    INTPK        YES        NO       NO
C     3T        UNPACK  GETSTR   INTPK        YES        NO       NO
C  NEW METHODS
C     10        UNPACK  UNPACK   UNPACK       YES        NO       NO
C     11        UNPACK  GETSTR   UNPACK       YES        NO       NO
C     20        UNPACK  UNPACK   UNPACK       NO         YES      YES
C     21        GETSTR  UNPACK   UNPACK       NO         YES      YES
C     30        GETSTR  UNPACK   UNPACK       YES        NO       NO
C     31        GETSTR  GETSTR   UNPACK       YES        NO       NO
C     40        UNPACK  GETSTR   UNPACK       NO         YES      YES
C     41        GETSTR  GETSTR   UNPACK       NO         YES      YES
C
      COMMON /MPYADX/ FILEA(7)     ,FILEB(7)     ,FILEC(7)     ,
     1                FILED(7)     ,NZ    ,T     ,SIGNAB,SIGNC ,PREC1 ,
     2                SCRTCH,TIME
      COMMON /SYSTEM/ KSYSTM(152)
      EQUIVALENCE     (KSYSTM(58), METHOD )
      CALL SSWTCH ( 49, L49 )
      IF ( METHOD .GE. 1 .AND. METHOD .LE. 3 ) L49 = 1 
      IF ( L49 .NE. 0 ) CALL MPYADO ( ZZ, Z, ZD )
      IF ( L49 .EQ. 0 ) CALL MMA    ( ZZ, Z, ZD )
      RETURN
      END

