      SUBROUTINE PLA3
C*****
C THIS ROUTINE COMPUTES ELEMENT STRESSES FOR NON-LINEAR (STRESS DEPEN-
C DENT) ELEMENTS FOR WHICH THE USER HAS REQUESTED STRESS OUTPUT.  IT
C ALSO UPDATES THE ESTNL DATA BLOCK SO THAT THE OUTPUT FILE, ESTNL1,
C CONTAINS UP-TO-DATE ELEMENT STRESS INFORMATION.
C
C DMAP CALL...
C
C  PLA3  CSTM,MPT,DIT,DELTAUGV,ESTNL,CASECC/ONLES,ESTNL1/V,N,PLACOUNT/
C        V,N,PLSETNO/ $
C
C THIS ROUTINE IS THE MODULE DRIVER...  SUBROUTINE PLA31 READS THE
C INCREMENTAL DISPLACEMENT VECTOR INTO CORE AND APPENDS THE PROPER
C DISPLACEMENT VALUES TO THE ESTNL ENTRY FOR EACH ELEMENT, THEREBY
C CREATING THE ESTNLS, THE ESTNL SCRATCH FILE.  IN PLA32, THE ESTNLS
C FILE IS READ, AND THE PROPER ELEMENT ROUTINE IS CALLED.  THE ELEMENT
C ROUTINE COMPUTES THE ELEMENT STRESSES AND STORES THIS INFORMATION IN
C THE BLOCK /SOUT/.  THE ELEMENT ROUTINE ALSO UPDATES THE EST ENTRY
C WHICH HAS BEEN COMMUNICATED TO TI VIA /PLA32E/.
C*****
C
C
C
      CALL PLA31
      CALL PLA32
      RETURN
      END
