      SUBROUTINE DELSET
C*****
C  THIS ROUTINE SETS VARIABLES FOR DUMMY ELEMENTS IN /GPTA1/
C
C  ALL MODULES USING /GPTA1/ SHOULD BE SURE TO CALL THIS ROUTINE
C  SO AS TO INSURE THAT DATA FOR ANY DUMMY ELEMENTS PRESENT GETS
C  INSERTED INTO /GPTA1/.
C*****
      INTEGER DUMTYP(9)
C
      COMMON/SYSTEM/ NSKIP(45), IDUM(9)
C
      COMMON/GPTA1 / NELEM, LAST, INCR, NE(1)
C
      DATA DUMTYP/53,54,55,56,57,58,59,60,61/
C
      DO 100 I = 1,9
      NGRIDS = IDUM(I) / 10000000
      NC = MOD( IDUM(I),10000000) / 10000
      NP = MOD( IDUM(I),10000) / 10
C
C     ND IS DECODE AND USED IN ROUTINES DS1 AND DS1A
C
      ND = MOD(IDUM(I), 10)
      IZERO = (DUMTYP(I) - 1)*INCR
      NE(IZERO+6) = NC + NGRIDS + 2
      NE(IZERO+9) = NP +2
      IF(NP.EQ. 0) NE(IZERO+9) =  0
      NE(IZERO+10) = NGRIDS
      N = 5*NGRIDS + 3 + NP + NC
      NE(IZERO+12) = N
      NE(IZERO+15) = NGRIDS + 2
  100 CONTINUE
      RETURN
      END
