      SUBROUTINE STRNAM ( IELT, ISCAN, NAME )
      CHARACTER*12    NAME
      LOGICAL        LAYERD
      COMMON / XSCANX / DUM(21), LAYERD
      COMMON / SYSTEM / ISYSBF, NOUT
C      PRINT *,' ENTERRING STRNAM,IELT,ISCAN=',IELT,ISCAN
      NAME= ' '
      IF ( IELT .NE. 1 .AND. IELT .NE. 3 .AND. IELT .NE. 10 ) GO TO 10
C ROD, TUBE, CONROD
      IF ( ISCAN .EQ. 2 ) NAME='AXIAL'
      IF ( ISCAN .EQ. 4 ) NAME='TORSIONAL'
      IF ( ISCAN .EQ. 3 ) NAME='MARGIN'
      IF ( ISCAN .EQ. 5 ) NAME='MARGIN'
      GO TO 7000
10    IF ( IELT .NE. 4 .AND. IELT .NE. 5 ) GO TO 20
C SHEAR, TWIST
      IF ( ISCAN .EQ. 2 ) NAME='MAX-SHR'
      IF ( ISCAN .EQ. 4 ) NAME='MARGIN'
      IF ( ISCAN .EQ. 3 ) NAME='AVG'
      GO TO 7000
20    IF ( IELT .NE. 6  .AND. IELT .NE. 17 .AND. IELT .NE. 19 .AND.
     &     IELT .NE. 18 .AND. IELT .NE. 7  .AND. IELT .NE. 8  .AND.
     &     IELT .NE. 15 ) GO TO 30
C TRIA1, TRIA2, QUAD1, QUAD2, TRBSC, TRPLT, QDPLT
      IF ( ISCAN .EQ. 3 .OR. ISCAN .EQ. 11 ) NAME='NORM-X'
      IF ( ISCAN .EQ. 4 .OR. ISCAN .EQ. 12 ) NAME='NORM-Y'
      IF ( ISCAN .EQ. 5 .OR. ISCAN .EQ. 13 ) NAME='SHEAR-XY'
      IF ( ISCAN .EQ. 7 .OR. ISCAN .EQ. 15 ) NAME='MAJOR'
      IF ( ISCAN .EQ. 8 .OR. ISCAN .EQ. 16 ) NAME='MINOR'
      IF ( ISCAN .EQ. 9 .OR. ISCAN .EQ. 17 ) NAME='MAX-SHR'
      GO TO 7000
30    IF ( IELT .NE. 9 .AND. IELT .NE. 16 .AND. IELT .NE. 62 .AND.
     &     IELT .NE. 63 ) GO TO 40
C TRMEM, QDMEM, QDMEM1, QDMEM2
      IF ( ISCAN .EQ. 2 ) NAME='NORM-X'
      IF ( ISCAN .EQ. 3 ) NAME='NORM-Y'
      IF ( ISCAN .EQ. 4 ) NAME='SHEAR-XY'
      IF ( ISCAN .EQ. 6 ) NAME='MAJOR'
      IF ( ISCAN .EQ. 7 ) NAME='MINOR'
      IF ( ISCAN .EQ. 8 ) NAME='MAX-SHR'
      GO TO 7000
40    IF ( IELT .NE. 11 .AND. IELT .NE. 12 .AND. IELT .NE. 13 .AND.
     &     IELT .NE. 80 ) GO TO 50
C ELAS1, ELAS2, ELAS3, IS2D8
      IF ( ISCAN .EQ. 2 ) NAME='OCT-SHR'
      GO TO 7000
50    IF ( IELT .NE. 34 .AND. IELT .NE. 81 ) GO TO 60
C BAR, ELBOW
      IF ( ISCAN .EQ. 7 .OR. ISCAN .EQ. 8 ) NAME='SB-MAX'
      IF ( ISCAN .EQ. 14.OR. ISCAN .EQ.15 ) NAME='SB-MAX'
      IF ( ISCAN .EQ. 9 .OR. ISCAN .EQ.16 ) NAME='MARGIN'
      IF ( ISCAN .EQ. 6 ) NAME='AXIAL'
      GO TO 7000
60    IF ( IELT .NE. 35 ) GO TO 70
C CONEAX
      IF ( ISCAN .EQ. 4 .OR. ISCAN .EQ. 22 ) NAME='NORM-U'
      IF ( ISCAN .EQ. 5 .OR. ISCAN .EQ. 23 ) NAME='NORM-V'
      IF ( ISCAN .EQ. 6 .OR. ISCAN .EQ. 24 ) NAME='SHEAR-UV'
      IF ( ISCAN .EQ. 8 .OR. ISCAN .EQ. 26 ) NAME='MAJOR'
      IF ( ISCAN .EQ. 9 .OR. ISCAN .EQ. 27 ) NAME='MINOR'
      IF ( ISCAN .EQ. 10.OR. ISCAN .EQ. 28 ) NAME='MAX-SHR'
      GO TO 7000
70    IF ( IELT .NE. 36 ) GO TO 80
C TRIARG
      IF ( ISCAN .EQ. 2 ) NAME='RADIAL'
      IF ( ISCAN .EQ. 3 ) NAME='CIRCUM'
      IF ( ISCAN .EQ. 4 ) NAME='AXIAL'
      IF ( ISCAN .EQ. 5 ) NAME='SHEAR'
      GO TO 7000
80    IF ( IELT .NE. 37 ) GO TO 90
C TRAPRG
      KSCAN = MOD( ISCAN, 4 )
      IF ( KSCAN .EQ. 2 .AND. ISCAN .NE. 18 ) NAME='RADIAL'
      IF ( KSCAN .EQ. 3 ) NAME='CIRCUM'
      IF ( KSCAN .EQ. 0 ) NAME='AXIAL'
      IF ( KSCAN .EQ. 1 ) NAME='SHEAR'
      IF ( KSCAN .EQ. 2 .AND. ISCAN .NE. 2 ) NAME='SHR-FORC'
      GO TO 7000
90    IF ( IELT .NE. 38 ) GO TO 100
C TORDRG
      KSCAN = MOD( ISCAN, 5 )
      IF ( KSCAN .EQ. 2 ) NAME='MEM-T'
      IF ( KSCAN .EQ. 3 ) NAME='MEM-C'
      IF ( KSCAN .EQ. 4 ) NAME='FLEX-T'
      IF ( KSCAN .EQ. 0 ) NAME='FLEX-C'
      IF ( KSCAN .EQ. 1 ) NAME='SHR-FORC'
      GO TO 7000
100   IF ( IELT .NE. 65 .AND. IELT .NE. 66 ) GO TO 110
C IHEX1, IHEX2
      KSCAN = MOD( ISCAN, 22 )
      IF ( KSCAN .EQ. 3 ) NAME='NORM-X'
      IF ( KSCAN .EQ. 4 ) NAME='SHEAR-XY'
      IF ( KSCAN .EQ. 5 ) NAME='PRINC-A'
      IF ( KSCAN .EQ. 9 ) NAME='MEAN'
      IF ( KSCAN .EQ.11 ) NAME='NORM-Y'
      IF ( KSCAN .EQ.12 ) NAME='SHEAR-YZ'
      IF ( KSCAN .EQ.13 ) NAME='PRINC-B'
      IF ( KSCAN .EQ.17 ) NAME='NORM-Z'
      IF ( KSCAN .EQ.18 ) NAME='SHEAR-ZX'
      IF ( KSCAN .EQ.19 ) NAME='PRINC-C'
      IF ( KSCAN .EQ.10 ) NAME='MAX-SHR'
      GO TO 7000
110   IF ( IELT .NE. 67 ) GO TO 120
C IHEX3
      KSCAN = MOD( ISCAN, 23 )
      IF ( KSCAN .EQ. 3 ) NAME='NORM-X'
      IF ( KSCAN .EQ. 4 ) NAME='SHEAR-XY'
      IF ( KSCAN .EQ. 5 ) NAME='PRINC-A'
      IF ( KSCAN .EQ. 9 ) NAME='MEAN'
      IF ( KSCAN .EQ.12 ) NAME='NORM-Y'
      IF ( KSCAN .EQ.13 ) NAME='SHEAR-YZ'
      IF ( KSCAN .EQ.14 ) NAME='PRINC-B'
      IF ( KSCAN .EQ.18 ) NAME='NORM-Z'
      IF ( KSCAN .EQ.19 ) NAME='SHEAR-ZX'
      IF ( KSCAN .EQ.20 ) NAME='PRINC-C'
      IF ( KSCAN .EQ.10 ) NAME='MAX-SHR'
      GO TO 7000
120   IF ( IELT .NE. 70 .AND. IELT .NE. 71 ) GO TO 130
C TRIAAX, TRAPAX
      KSCAN = MOD ( ISCAN, 8 )
      IF ( KSCAN .EQ. 3 ) NAME='RADIAL'
      IF ( KSCAN .EQ. 4 ) NAME='AXIAL'
      IF ( KSCAN .EQ. 5 ) NAME='CIRCUM'
      IF ( KSCAN .EQ. 6 ) NAME='MEM-C'
      IF ( KSCAN .EQ. 7 ) NAME='FLEX-T'
      IF ( KSCAN .EQ. 0 ) NAME='FLEX-C'
      GO TO 7000
130   IF ( IELT .NE. 64 .AND. IELT .NE. 83 ) GO TO 150
C QUAD4, TRIA3 WITHOUT LAMINATION
      IF ( LAYERD ) GO TO 140
      IF ( ISCAN .EQ. 3 .OR. ISCAN .EQ. 11 ) NAME='NORMAL-X'
      IF ( ISCAN .EQ. 4 .OR. ISCAN .EQ. 12 ) NAME='NORMAL-Y'
      IF ( ISCAN .EQ. 5 .OR. ISCAN .EQ. 13 ) NAME='SHEAR-XY'
      IF ( ISCAN .EQ. 7 .OR. ISCAN .EQ. 15 ) NAME='MAJOR'
      IF ( ISCAN .EQ. 18.OR. ISCAN .EQ. 16 ) NAME='MINOR'
      IF ( ISCAN .EQ. 9 .OR. ISCAN .EQ. 17 ) NAME='MAX-SHR'
      GO TO 7000
140   CONTINUE
C   QUAD4 AND TRIA3 WITH LAMINATION
      KSCAN = MOD( ISCAN, 10 )
      IF ( ISCAN .EQ. 5 ) NAME='NORMAL-1'
      IF ( ISCAN .EQ. 6 ) NAME='NORMAL-2'
      IF ( ISCAN .EQ. 7 ) NAME='SHEAR-12'
      IF ( ISCAN .EQ. 0 ) NAME='SHEAR-1Z'
      IF ( ISCAN .EQ. 1 ) NAME='SHEAR-2Z'
      GO TO 7000
150   WRITE ( NOUT, 901 ) IELT
901   FORMAT(//,' SCAN MODULE PROCESSING UNKNOWN ELEMENT NUMBER '
     &       ,I8,//)
      CALL MESAGE( -61,0,0)
7000  CONTINUE
C      PRINT *,' RETURNING FROM STRNAM,FIELD=',NAME
      RETURN
      END
