      SUBROUTINE MODC
C
C*****
C
C     DUMMY DECK FOR MODULE MODC   SEE USERS MANUAL SECTION 5.3
C                                  FOR MODULE PROPERTIES CHECK XMPLBD
C                                  OR USE DIAG 29
C
C*****
C
C     INTEGER INFILE(2)
C
      COMMON /BLANK/ IPARM
C
C     DATA INFILE /101,102/
C
      RETURN
      END
