      SUBROUTINE IDF1 (EE,E2,    ETA01,ZET01,ARE,AIM,BRE,BIM,CRE,CIM,
     1                 R1SQX,XIIJR,XIIJI)
C   ***   INTEGRATES THE PLANAR PARTS OF THE INCREMENTAL
C         OSCILLATORY KERNELS FOR UNSTEADY CASES
      PI   = 3.1415926
      PARN = ETA01**2 - ZET01**2
      FACR = PARN*ARE + ETA01*BRE + CRE
      FACI = PARN*AIM + ETA01*BIM + CIM
      PARNR= BRE/2.0  + ETA01*ARE
      PARNI= BIM/2.0  + ETA01*AIM
      UP   = (ETA01-EE)**2 + ZET01**2
      DOWN = (ETA01+EE)**2 + ZET01**2
      ARG2 = UP/DOWN
      ALARG2 = ALOG(ARG2)
      TRM2R= PARNR * ALOG(ARG2)
      TRM2I= PARNI * ALOG(ARG2)
      TRM3R= 2.0*EE* ARE
      TRM3I= 2.0*EE* AIM
      AZET = ABS(ZET01)
      IF  ((AZET/EE) . LE . 0.001)  GO TO  100
      TEST0= ABS((R1SQX-E2)/(2.0*EE*AZET))
      IF (TEST0.LE.0.0001)  GO TO 110
      COEF = (2.0*EE)/(R1SQX-E2)
      ARGA = COEF*ZET01
      TEST = ABS(ARGA)
      IF (TEST.LE.0.3)  GO TO 120
      ARGT = COEF*AZET
      ATANA= ATAN(ARGT)
      FUNCT= ATANA/AZET
      GO TO 170
  100 CONTINUE
      FUNCT= (2.0*EE)/(ETA01**2-E2)
      GO TO 170
  110 CONTINUE
      FUNCT= 0.0
      GO TO 170
  120 CONTINUE
      S    = ARGA**2
      SER  = 1./3.+S*(-1./5.+S*(1./7.+S*(-1./9.+S*(1./11.-S/13.))))
      ALPHA= E2*(COEF**2)*SER
      FUNCT= COEF*(1.0-ALPHA*(ZET01**2)/E2)
  170 CONTINUE
      TRM1R= FACR * FUNCT
      TRM1I= FACI * FUNCT
      XIIJR= TRM1R + TRM2R + TRM3R
      XIIJI= TRM1I + TRM2I + TRM3I
      RETURN
      END
