      SUBROUTINE DPPSB(  KS,I,J1,J2,SGR,CGR,           YS,ZS,NBARAY,
     1           NCARAY,DT,Z)
C   ***   GENERATES ROWS OF THE  DPP  SUBMATRIX USING
C         SUBROUTINE  SUBP
      INTEGER Z
      DIMENSION YS(1),ZS(1),NBARAY(1),NCARAY(1),Z(1)
      COMPLEX SUM,DT(1)
      COMMON /DLBDY/ NJ1,NK1,NP,NB,NTP,NBZ,NBY,NTZ,NTY,NT0,NTZS,NTYS,
     *   INC,INS,INB,INAS,IZIN,IYIN,INBEA1,INBEA2,INSBEA,IZB,IYB,
     *   IAVR,IARB,INFL,IXLE,IXTE,INT121,INT122,IZS,IYS,ICS,IEE,ISG,
     *   ICG,IXIJ,IX,IDELX,IXIC,IXLAM,IA0,IXIS1,IXIS2,IA0P,IRIA
     *  ,INASB,IFLA1,IFLA2,ITH1A,ITH2A,
     *   ECORE,NEXT,SCR1,SCR2,SCR3,SCR4,SCR5
      L    = 1
C  L IS THE PANEL NUMBER ASSOCIATED WITH SENDING   POINT  J
      LS   = 1
      LSP = 0
C  LS IS THE STRIP NUMBER ASSOCIATED WITH SENDING   POINT  J
      NBXS = NBARAY(L)
      NC1  = NCARAY(L)
      NBCUM= NC1
      YREC = YS(KS)
      ZREC = ZS(KS)
      DO   20  J=J1,J2
      CALL SUBPB(I,L,LS,J,SGR,CGR,YREC,ZREC,SUM,Z(IXIC),Z(IDELX),Z(IEE)
     * ,Z(IXLAM),Z(ISG),Z(ICG),Z(IYS),Z(IZS),Z(INAS),Z(INASB+LSP),
     *  Z(IAVR),Z(IZB),Z(IYB),Z(IARB),Z(IXLE),Z(IXTE),Z(IX),NB)
      DT(J)= SUM
      IF (J.EQ.J2)  GO TO   20
      IF (J.LT.NBXS)   GO TO  10
      LSP = LSP + Z(INAS+L-1)
      L    = L+1
      NC1  = NCARAY(L)
      NBXS = NBARAY(L)
   10 CONTINUE
      IF (J.LT.NBCUM)  GO TO  20
      LS   = LS+1
      NBCUM= NBCUM+NC1
   20 CONTINUE
      RETURN
      END
