      SUBROUTINE AKAPPA (ARG,BKAPPA)
C
C     SUBROUTINE FOR COMPUTING KAPPA
C
      COMPLEX AI
C
      COMMON/BLK1/SCRK,SPS,SNS,DSTR,AI,PI,DEL,SIGMA,BETA,RES
C
      SCRK1 =  ABS (SCRK)
      ARG1  =  ABS (ARG)
      IF ( SCRK1 .GT. ARG1)  GO TO 10
      GAM=SQRT(ARG**2-SCRK**2)
      S1=SNS*GAM
      C1=BETA*GAM*SIN(S1)
      C2=COS(S1)-COS((ARG-DEL)*SPS+SIGMA)
      BKAPPA=C1/C2
      RETURN
   10 CONTINUE
      GAM=SQRT(SCRK**2-ARG**2)
      S1=SNS*GAM
      C1=-BETA*GAM*SINH(S1)
      C2=COSH(S1)-COS((ARG-DEL)*SPS+SIGMA)
      BKAPPA=C1/C2
      RETURN
      END
