      SUBROUTINE FVRS1B (BASE,W1,NF)
C
C     SUBROUTINE TO COMPUTE BASE(FI)(3X1) FOR MODFRL=FALSE
C
      COMPLEX BASE(3,NF),Z1,P
C
      DIMENSION W1(NF)
C
      COMMON /CONDAS/ PI,TWOPI,RADEG,DEGRA,S4PIQ
      COMMON /BLANK / DUM(5),IT(6),DUM1(3)
C
      DO 110 K=1,NF
      F=W1(K)/TWOPI
      LT=1
      LP=2
      DO 100 I=1,3
      IF(IT(LT).EQ.-1)GO TO 90
      CALL TAB(IT(LT),F,XO)
      IF(IT(LP).EQ.-1)GO TO 40
      CALL TAB(IT(LP),F,PHI)
      RAD=PHI*DEGRA
      Z1=CMPLX(0.0,RAD)
      P=CEXP(Z1)
      GO TO 50
  40  P=(1.0,0.0)
  50  BASE(I,K)=XO*P
      GO TO 95
  90  BASE(I,K)=(0.0,0.0)
  95  LT=LT+2
      LP=LP+2
 100  CONTINUE
 110  CONTINUE
      RETURN
      END
